@@ -6,16 +6,17 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
-	installer "github.com/openshift/installer/pkg/types"
+	corev1 "k8s.io/api/core/v1"
+	metaapi "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/util/yaml"
 
 	configv1 "github.com/openshift/api/config/v1"
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
-	corev1 "k8s.io/api/core/v1"
-	metaapi "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/util/yaml"
+	installer "github.com/openshift/installer/pkg/types"
+
+	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 )
 
 var (
@@ -74,6 +75,7 @@ func GetInfrastructure(listers *regopclient.Listers) (*configv1.Infrastructure,
 
 	if infra.Status.PlatformStatus == nil {
 		infra.Status.PlatformStatus = &configv1.PlatformStatus{
+			//nolint:staticcheck
 			Type: infra.Status.Platform,
 		}
 
@@ -117,7 +119,7 @@ func GetValueFromSecret(sec *corev1.Secret, key string) (string, error) {
 // medium that the registry will use
 func GenerateStorageName(listers *regopclient.Listers, additionalInfo ...string) (string, error) {
 	// Get the infrastructure name
-	infra, err := listers.Infrastructures.Get("cluster")
+	infra, err := GetInfrastructure(listers)
 	if err != nil {
 		return "", err
 	}
